@@ -38,6 +38,8 @@ class fMMS_GUI(hildon.Program):
 		self.ch = ContactH.ContactHandler()
 		self.osso_c = osso.Context("fMMS", self.config.get_version(), False)
 		self.osso_rpc = osso.Rpc(self.osso_c)
+		
+		self.refreshlistview = True
 	
 		if not os.path.isdir(self._mmsdir):
 			log.info("creating dir %s", self._mmsdir)
@@ -136,13 +138,6 @@ class fMMS_GUI(hildon.Program):
 		
 		self.window.show_all()
 		self.add_window(self.window)
-		
-		if self.config.get_firstlaunch() == 1:
-			note = osso.SystemNote(self.osso_c)
-			firstlaunchmessage = "NOTE: Currently you have to connect manually to the MMS APN when sending and receiving.\nAlso, only implemented attachment is image."
-			note.system_note_dialog(firstlaunchmessage , 'notice')
-			self.create_config_dialog()
-			self.config.set_firstlaunch(0)
 
 
 	""" need this to always have the current path """
@@ -155,14 +150,25 @@ class fMMS_GUI(hildon.Program):
 
 
 	def cb_on_focus(self, widget, event):
-		t1 = time.clock()
-		hildon.hildon_gtk_window_set_progress_indicator(self.window, 1)
-		self.force_ui_update()
-		self.liststore.clear()
-		self.add_buttons_liststore()
-		hildon.hildon_gtk_window_set_progress_indicator(self.window, 0)
-		t2 = time.clock()
-		log.info("liststore time: %s" % round(t2-t1, 3))
+		if self.refreshlistview == True:
+			t1 = time.clock()
+			hildon.hildon_gtk_window_set_progress_indicator(self.window, 1)
+			self.force_ui_update()
+			self.liststore.clear()
+			self.add_buttons_liststore()
+			hildon.hildon_gtk_window_set_progress_indicator(self.window, 0)
+			t2 = time.clock()
+			log.info("liststore time: %s" % round(t2-t1, 3))
+			self.refreshlistview = False
+			
+			if self.config.get_firstlaunch() == 1:
+						note = osso.SystemNote(self.osso_c)
+						firstlaunchmessage = "NOTE: Currently you have to connect manually to the MMS APN when sending and receiving.\nOnly implemented attachment is image."
+						note = hildon.hildon_note_new_information(self.window, firstlaunchmessage)
+						self.create_config_dialog()
+						self.config.set_firstlaunch(0)
+						note.run()
+						note.destroy()
 		return True
 
 
@@ -185,10 +191,12 @@ class fMMS_GUI(hildon.Program):
 			return
 		elif method == 'send_mms':
 			log.info("launching sender with args: %s", args)
+			self.refreshlistview = True
 			fMMSSenderUI.fMMS_SenderUI(tonumber=args[0]).run()
 			return
 		elif method == 'send_via_service':
 			log.info("launching sendviaservice with args: %s", args)
+			self.refreshlistview = True
 			ret = fMMSSenderUI.fMMS_SenderUI(withfile=args[0], subject=args[1], message=args[2]).run()
 			return ret
 		
@@ -221,6 +229,7 @@ class fMMS_GUI(hildon.Program):
 	
 	def new_mms_button_clicked(self, button):
 		ret = fMMSSenderUI.fMMS_SenderUI(self.window).run()
+		self.refreshlistview = True
 		
 		
 	def create_about_dialog(self):
@@ -239,6 +248,7 @@ class fMMS_GUI(hildon.Program):
 
 	def create_config_dialog(self):
 		dialog = gtk.Dialog()
+		#dialog.set_transient_for(self.window)
 		dialog.set_title("Configuration")
 		
 		allVBox = gtk.VBox()
@@ -307,14 +317,9 @@ class fMMS_GUI(hildon.Program):
 		allVBox.show_all()
 		dialog.vbox.add(allVBox)
 		dialog.add_button("Save", gtk.RESPONSE_APPLY)
-		while 1:
-			ret = dialog.run()
-			ret2 = self.config_menu_button_clicked(ret)
-			if ret2 == 0 or ret2 == None: 
-				break
-			
+		ret = dialog.run()
+		ret2 = self.config_menu_button_clicked(ret)
 		dialog.destroy()
-		return ret
 
 		
 	""" from http://faq.pygtk.org/index.py?req=show&file=faq14.005.htp """
@@ -403,6 +408,7 @@ class fMMS_GUI(hildon.Program):
 			
 			primarytxt = self.cont.get_primary_font().to_string()
 			primarycolor = self.cont.get_primary_color().to_string()
+			highlightcolor = self.cont.get_active_color().to_string()
 			secondarytxt = self.cont.get_secondary_font().to_string()
 			secondarycolor = self.cont.get_secondary_color().to_string()
 			for varlist in pushlist:
@@ -451,8 +457,11 @@ class fMMS_GUI(hildon.Program):
 						description = varlist['Subject']
 					except:
 						description = ""
+						
 				primarytext = ' <span font_desc="%s" foreground="%s"><sup>%s</sup></span>' % (secondarytxt, secondarycolor, mtime)
 				secondarytext = '\n<span font_desc="%s" foreground="%s">%s</span>' % (secondarytxt, secondarycolor, description)
+				if not isread and direction == fMMSController.MSG_DIRECTION_IN:
+					sender = '<span foreground="%s">%s</span>' % (highlightcolor, sender)
 				stringline = "%s%s%s" % (sender, primarytext, secondarytext)
 				self.liststore.append([icon, stringline, photo, fname, sender])
 
@@ -482,11 +491,13 @@ class fMMS_GUI(hildon.Program):
 	def delete_push_mms(self, fname):
 		try:
 			self.cont.wipe_message(fname)
-			banner = hildon.hildon_banner_show_information(self.window, "", "fMMS: Message deleted")
+			#banner = hildon.hildon_banner_show_information(self.window, "", "fMMS: Message deleted")
+			self.refreshlistview = True
 		except Exception, e:
 			log.exception("%s %s", type(e), e)
-			raise
+			#raise
 			banner = hildon.hildon_banner_show_information(self.window, "", "fMMS: Failed to delete message.")
+			self.refreshlistview = True
 
 
 	""" action on delete contextmenu click """
@@ -512,6 +523,7 @@ class fMMS_GUI(hildon.Program):
 			self.delete_push_mms(filename)
 			#self.liststore.remove(miter)
 		dialog.destroy()
+		self.refreshlistview = True
 		return
 	
 
@@ -547,6 +559,7 @@ class fMMS_GUI(hildon.Program):
 			log.exception("%s %s", type(e), e)
 			#raise
 		hildon.hildon_gtk_window_set_progress_indicator(self.window, 0)
+		self.refreshlistview = True
 
 
 	def run(self):
