@@ -88,7 +88,9 @@ class fMMS_SenderUI(hildon.Program):
 		
 		self.tvMessage = hildon.TextView()
 		self.tvMessage.set_property("name", "hildon-fullscreen-textview")
-		self.tvMessage.set_wrap_mode(gtk.WRAP_WORD)
+		self.tvMessage.set_pixels_above_lines(-1)
+		self.tvMessage.set_pixels_below_lines(-1)
+		self.tvMessage.set_wrap_mode(gtk.WRAP_CHAR)
 		if message != None and message != '':
 			tb = gtk.TextBuffer()
 			tb.set_text(message)
@@ -197,7 +199,25 @@ class fMMS_SenderUI(hildon.Program):
 		if filetype.startswith("image"):
 			im = Image.open(filename)
 			im.thumbnail((256,256), Image.NEAREST)
-			pixbuf = self.image2pixbuf(im)
+			pixbuf = self.cont.image2pixbuf(im)
+			image = gtk.Image()
+			image.set_from_pixbuf(pixbuf)
+			self.imageBox.remove(self.imageBoxContent)
+			self.imageBoxContent = image
+			self.imageBox.add(self.imageBoxContent)
+			self.imageBox.show_all()
+		elif filetype.startswith("audio"):
+			icon_theme = gtk.icon_theme_get_default()
+			pixbuf = icon_theme.load_icon("mediaplayer_default_album", 128, 0)
+			image = gtk.Image()
+			image.set_from_pixbuf(pixbuf)
+			self.imageBox.remove(self.imageBoxContent)
+			self.imageBoxContent = image
+			self.imageBox.add(self.imageBoxContent)
+			self.imageBox.show_all()
+		elif filetype.startswith("video"):
+			icon_theme = gtk.icon_theme_get_default()
+			pixbuf = icon_theme.load_icon("general_video", 128, 0)
 			image = gtk.Image()
 			image.set_from_pixbuf(pixbuf)
 			self.imageBox.remove(self.imageBoxContent)
